@@ -7,7 +7,7 @@
 """
 from flask import current_app, Markup, Blueprint, url_for
 
-try:
+try:  # pragma: no cover
     from wtforms.fields import HiddenField
 except ImportError:
     def is_hidden_field_filter(field):
@@ -30,7 +30,7 @@ def get_table_titles(data, primary_key, primary_key_title):
     if not data:
         return []
     titles = []
-    for k in data[0].__table__.columns._data.keys():
+    for k in data[0].__table__.columns.keys():
         if not k.startswith('_'):
             titles.append((k, k.replace('_', ' ').title()))
     titles[0] = (primary_key, primary_key_title)
@@ -91,7 +91,7 @@ class Bootstrap(object):
                     ' type="text/css">' % (version, css_filename)
             else:
                 css = '<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootswatch@%s/dist/%s/%s"' \
-                    ' type="text/css"' % (version, bootswatch_theme.lower(), css_filename)
+                    ' type="text/css">' % (version, bootswatch_theme.lower(), css_filename)
         return Markup(css)
 
     @staticmethod
